@@ -1,16 +1,15 @@
 # -*- coding: utf-8 -*-
 
 ###
-### $Rev$
-### $Release: 0.0.1 $
-### copyright(c) 2008 kuwata-lab.com all rights reserved.
+### $Release: 0.0.2 $
+### copyright(c) 2008-2009 kuwata-lab.com all rights reserved.
 ### MIT License
 ###
 
-__RELEASE__ = "$Release: 0.0.1 $".split(' ')[1]
+__RELEASE__ = "$Release: 0.0.2 $".split(' ')[1]
 __all__ = (
     'KookError', 'KookRecipeError', 'KookCommandError',
-    #'product', 'ingreds', 'byprods', 'coprods', 'priority', 'cmdopts', 'if_exists',
+    #'product', 'ingreds', 'byprods', 'coprods', 'priority', 'spices', 'if_exists',
     #'Recipe', 'TaskRecipe', 'FileRecipe',
     #'Cookbook', 'Kitchen', # 'Cookable', 'Material', 'Cooking', 'create_context',
 )
@@ -19,7 +18,7 @@ import sys, os, re, types
 from kook.utils import *
 
 
-class KookError(StandardError):
+class KookError(Exception):  # StandardError is not available in Python 3.0
     pass
 
 
