@@ -1,9 +1,8 @@
 # -*- coding: utf-8 -*-
 
 ###
-### $Rev$
-### $Release: 0.0.1 $
-### copyright(c) 2008 kuwata-lab.com all rights reserved.
+### $Release: 0.0.2 $
+### copyright(c) 2008-2009 kuwata-lab.com all rights reserved.
 ### MIT License
 ###
 
@@ -35,10 +34,10 @@ class Cookbook(object):
         #    self.load_file(bookname)
 
     def prop(self, name, value):
-        if not self._property_names_dict.has_key(name):
+        if name not in self._property_names_dict:
             self._property_names_dict[name] = True
             self.property_names.append(name)
-        if self.context.has_key(name):
+        if name in self.context:
             value = self.context[name]
         else:
             self.context[name] = value
@@ -72,13 +71,14 @@ class Cookbook(object):
         if properties: context.update(properties)
         context['prop'] = self.prop
         self.context = context
-        exec code_obj in context, context
+        exec(code_obj, context, context)
         ## create recipes
         recipes = {
             'task': {'specific': [], 'generic': []},
             'file': {'specific': [], 'generic': []},
         }
-        for name, obj in context.iteritems():
+        for name in context:         # dict.iteritems() is not available in Python 3.0
+            obj = context.get(name)
             if name == 'kook_materials':
                 if not isinstance(obj, (tuple, list)):
                     raise KookRecipeError("kook_materials: tuple or list expected.")
@@ -160,13 +160,13 @@ class Recipe(object):
 
     kind = None
 
-    def __init__(self, product=None, ingreds=(), byprods=(), func=None, desc=None, cmdopts=None):
+    def __init__(self, product=None, ingreds=(), byprods=(), func=None, desc=None, spices=None):
         self.product = product
         self.ingreds = ingreds
         self.byprods = byprods
         self.func    = func
         self.desc    = desc
-        self.cmdopts = cmdopts
+        self.spices = spices
         if not product:
             self.pattern = None
         elif type(product) is _re_pattern_type:
@@ -186,10 +186,10 @@ class Recipe(object):
             return self.product == target
 
     def get_func_name(self):
-        return self.func.func_code.co_name
+        return kook.utils._get_codeobj(self.func).co_name
 
     def _func_linenum(self):
-        return self.func.func_code.co_firstlineno
+        return kook.utils._get_codeobj(self.func).co_firstlineno
 
     @classmethod
     def new(cls, func_name, func, prefix, _cls=None):
@@ -197,11 +197,11 @@ class Recipe(object):
         product = getattr(func, '_kook_product', func_name[len(prefix):])
         ingreds = getattr(func, '_kook_ingreds', ())
         byprods = getattr(func, '_kook_byprods', ())
-        cmdopts = getattr(func, '_kook_cmdopts', None)
+        spices = getattr(func, '_kook_spices', None)
         func    = func
         desc    = func.__doc__  ## can be empty string
         if desc is None: desc = _default_descs.get(product)
-        return _cls(product=product, ingreds=ingreds, byprods=byprods, func=func, desc=desc, cmdopts=cmdopts)
+        return _cls(product=product, ingreds=ingreds, byprods=byprods, func=func, desc=desc, spices=spices)
 
     def __repr__(self):
         #return "<%s product=%s func=%s>" % (self.__class__.__name__, repr(self.product), self.get_func_name())
