@@ -1,9 +1,8 @@
 # -*- coding: utf-8 -*-
 
 ###
-### $Rev$
-### $Release: 0.0.1 $
-### copyright(c) 2008 kuwata-lab.com all rights reserved.
+### $Release: 0.0.2 $
+### copyright(c) 2008-2009 kuwata-lab.com all rights reserved.
 ### MIT License
 ###
 
@@ -11,7 +10,7 @@
 #from kook.kitchen import IfExists
 from kook.utils import flatten
 
-__all__ = ('product', 'ingreds', 'byprods', 'coprods', 'priority', 'cmdopts', 'if_exists', )
+__all__ = ('product', 'ingreds', 'byprods', 'coprods', 'priority', 'spices', 'cmdopts', 'if_exists', )
 
 
 def product(name):
@@ -52,13 +51,20 @@ def priority(level):
     return deco
 
 
-def cmdopts(*names):
+def spices(*names):
     def deco(f):
-        f._kook_cmdopts = names
+        f._kook_spices = names
         return f
     return deco
 
 
+def cmdopts(*names):
+    import sys
+    sys.stderr.write("[pykook] ERROR: '@cmdopts()' is obsolete. Use '@spices()' instead.\n")
+    sys.stderr.write("[pykook]        See http://www.kuwata-lab.com/kook/pykook-CHANGES.txt for details.\n")
+    sys.exit(1)
+
+
 def if_exists(*args):
     import kook
     #return kook.kitchen.IfExists(*args)
