@@ -1,9 +1,8 @@
 # -*- coding: utf-8 -*-
 
 ###
-### $Rev$
-### $Release: 0.0.1 $
-### copyright(c) 2008 kuwata-lab.com all rights reserved.
+### $Release: 0.0.2 $
+### copyright(c) 2008-2009 kuwata-lab.com all rights reserved.
 ### MIT License
 ###
 
@@ -75,8 +74,9 @@ class Main(object):
         props = {}
         if os.path.isfile("Properties.py"):
             content = read_file("Properties.py")
-            exec content in props, props
-            for name in props.keys():
+            #exec content in props, props
+            exec(content, props, props)
+            for name in list(props.keys()):
                 if not re.match(r'[a-zA-Z]', name):
                     del props[name]
         if longopts:
@@ -128,8 +128,8 @@ class Main(object):
             for recipe in recipes:
                 if show_all or recipe.desc:
                     write(format % (recipe.product, recipe.desc or ''))
-                    if kook._quiet or not recipe.cmdopts: continue
-                    optparser = CommandOptionParser.new(recipe.cmdopts)
+                    if kook._quiet or not recipe.spices: continue
+                    optparser = CommandOptionParser.new(recipe.spices)
                     for opt, desc in optparser.helps:
                         write(format2 % (opt, desc))
             write("\n")
@@ -169,11 +169,29 @@ class Main(object):
         try:
             status = self.invoke()
             sys.exit(status)
-        except Exception, ex:
-            ## show errors
-            ex_classes = (CommandOptionError, )   # or (CommandOptionError, KookError)
+        except Exception:
+            ex = sys.exc_info()[1]
+            ## show command option error
+            ex_classes = (CommandOptionError, kook.KookCommandError, kook.KookRecipeError)   # or (CommandOptionError, KookError)
             if isinstance(ex, ex_classes):
+                if not isinstance(ex, CommandOptionError):
+                    self.stderr.write("*** ERROR\n")
                 self.stderr.write(self.command + ": " + str(ex) + "\n")
+            ## system() failed
+            if isinstance(ex, kook.KookCommandError):
+                #self.stderr.write(self.command + ": " + str(ex) + "\n")
+                traceback_obj = sys.exc_info()[2]
+                import traceback
+                found = False
+                for tupl in reversed(traceback.extract_tb(traceback_obj)):
+                    filename, linenum, func_name, message = tupl
+                    if filename.endswith('Kookbook.py'):
+                        found = True
+                        break
+                if found:
+                    self.stderr.write("%s:%s: %s\n" % (filename, linenum, message))
+                else:
+                    traceback.print_tb(traceback_obj, file=sys.stderr)
             ## kick emacsclient when $E defined
             if os.environ.get('E'):
                 import traceback
@@ -192,4 +210,3 @@ class Main(object):
             ## re-raise exception when debug mode
             if not isinstance(ex, ex_classes) or kook._debug_level > 0:
                 raise
-            sys.exit(1)
