@@ -1,20 +1,22 @@
 # -*- coding: utf-8 -*-
 
 ###
-### $Rev$
-### $Release: 0.0.1 $
-### copyright(c) 2008 kuwata-lab.com all rights reserved.
+### $Release: 0.0.2 $
+### copyright(c) 2008-2009 kuwata-lab.com all rights reserved.
 ### MIT License
 ###
 
-import os, re
+import sys, os, re
 from glob import glob
 
+python2 = sys.version_info[0] == 2
+python3 = sys.version_info[0] == 3
 
-class ArgumentError(StandardError):
+
+class ArgumentError(Exception):
 
     def __init__(self, *args):
-        StandardError.__init__(self, *args)
+        Exception.__init__(self, *args)
 
 
 def str2int(s):
@@ -24,34 +26,48 @@ def str2int(s):
         return None
 
 
-def read_file(filename):
-    f = open(filename, 'r')
-    s = f.read()
-    f.close()
-    return s
+if python2:
 
+    def read_file(filename, encoding=None):
+        f = open(filename, 'rb')
+        try:
+            content = f.read()
+        finally:
+            f.close()
+        if encoding:
+            content = content.decode(encoding)
+        return content
 
-def write_file(filename, content):
-    f = open(filename, 'w')
-    f.write(content)
-    f.close()
+    def write_file(filename, content, encoding=None):
+        if isinstance(content, unicode):
+            content = content.encode(encoding or 'utf-8')
+        f = open(filename, 'wb')
+        try:
+            f.write(content)
+        finally:
+            f.close()
 
+elif python3:
 
-def flatten(items, _arr=None):
-    """flatten nested list or tuple."""
-    def _flatten(items, _arr):
-        for item in items:
-            if isinstance(item, (list, tuple)):
-                flatten(item, _arr)
-            else:
-                _arr.append(item)
-    _arr = []
-    #_flatten(items, _arr)
-    if isinstance(item, (list, tuple)):
-        flatten(item, _arr)
-    else:
-        _arr.append(item)
-    return _arr
+    def read_file(filename, encoding='utf-8'):
+        if encoding is False:
+            f = open(filename, 'rb')
+        else:
+            f = open(filename, 'r', encoding=(encoding or 'utf-8'))
+        try:
+            return f.read()
+        finally:
+            f.close()
+
+    def write_file(filename, content, encoding='utf-8'):
+        if encoding is False:
+            f = open(filename, 'wb')
+        else:
+            f = open(filename, 'w', encoding=(encoding or 'utf-8'))
+        try:
+            f.write(content)
+        finally:
+            f.close()
 
 
 def flatten(items, _arr=None):
@@ -93,7 +109,7 @@ def meta2rexp(pattern):
         if ch == '\\':
             i += 1
             if i >= n:
-                raise StandardError("%s: invalid pattern." % pattern)
+                raise ArgumentError("%s: invalid pattern." % pattern)  # or StandardError
             ch = pattern[i]
             buf.append(ch)
         elif ch == '*':
@@ -117,7 +133,7 @@ def meta2rexp(pattern):
                     break
                 i += 1
             if right is None:
-                raise StandardError("%s: '{' is not closed by '}'." % pattern)
+                raise ArgumentError("%s: '{' is not closed by '}'." % pattern)  # or StandardError
             words = pattern[left+1:right].split(',')
             buf.extend(('(', '|'.join(words), ')', ))
         else:
@@ -155,6 +171,8 @@ def glob2(pattern):
     else:
         dirpat += '*'
     filenames = []
+    if dirpat == '*':
+        filenames.extend(glob(basepat))
     for path in glob(dirpat):
         dirlist = _listup(path, 'd')
         for dir in dirlist:
@@ -163,7 +181,7 @@ def glob2(pattern):
     return filenames
 
 
-class CommandOptionError(StandardError):
+class CommandOptionError(Exception):   # StandardError is not available in Python 3.0
     pass
 
 
@@ -172,15 +190,15 @@ class CommandOptionParser(object):
     uncheck_longopts = False
 
     def __init__(self, optdef_strs=()):
-        self.parse_optdefs(optdef_strs)
+        self.parse_spices(optdef_strs)
 
     @classmethod
     def new(cls, optdef_strs=()):
         return cls(optdef_strs)
 
-    def parse_optdefs(self, optdef_strs):
+    def parse_spices(self, optdef_strs):
         helps = []
-        optdefs = {}
+        spices = {}
         for optdef_str in optdef_strs:
             opt, desc = optdef_str.split(':', 1)
             if desc: desc = desc.strip()
@@ -189,23 +207,23 @@ class CommandOptionParser(object):
             m = re.match(r'^-(\w)(?:\s+(.+)|\[(\w+)\])?$', opt)
             if m:
                 name, arg1, arg2 = m.group(1), m.group(2), m.group(3)
-                #optdefs[name] = arg1 and arg1 or (arg2 and True or False)
-                if   arg1:  optdefs[name] = arg1
-                elif arg2:  optdefs[name] = arg2 == 'N' and 1 or True
-                else:       optdefs[name] = False
+                #spices[name] = arg1 and arg1 or (arg2 and True or False)
+                if   arg1:  spices[name] = arg1
+                elif arg2:  spices[name] = arg2 == 'N' and 1 or True
+                else:       spices[name] = False
                 continue
             m = re.match(r'^--([a-zA-Z][-\w]+)(?:=(.+)|\[=(.+)\])?$', opt)
             if m:
                 name, arg1, arg2 = m.group(1), m.group(2), m.group(3)
-                #optdefs[name] = arg1 and arg1 or (arg2 and True or False)
-                if   arg1:  optdefs[name] = arg1
-                elif arg2:  optdefs[name] = arg2 == 'N' and 1 or True
-                else:       optdefs[name] = False
+                #spices[name] = arg1 and arg1 or (arg2 and True or False)
+                if   arg1:  spices[name] = arg1
+                elif arg2:  spices[name] = arg2 == 'N' and 1 or True
+                else:       spices[name] = False
                 continue
             raise ArgumentError("%s: invalid command optin definition." % optdef_str)
-        self.optdefs = optdefs
+        self.spices = spices
         self.helps = helps
-        return optdefs, help
+        return spices, help
 
     def parse(self, cmd_args, command=None):
         opts, rests = self._parse(cmd_args, command, check_longopts=True)
@@ -216,7 +234,7 @@ class CommandOptionParser(object):
         return opts, longopts, rests
 
     def _parse(self, cmd_args, command=None, check_longopts=True):
-        optdefs = self.optdefs
+        spices = self.spices
         i = 0
         N = len(cmd_args)
         opts = {}
@@ -232,23 +250,23 @@ class CommandOptionParser(object):
                 if not check_longopts:
                     if arg is None: arg = True
                     longopts[name] = arg
-                elif not optdefs.has_key(name):
+                elif name not in spices:
                     raise CommandOptionError("%s: unknown command option." % cmd_arg)
-                elif optdefs[name] is False:    # --name
+                elif spices[name] is False:    # --name
                     if arg is not None:
                         raise CommandOptionError("%s: argument is now allowed." % cmd_arg)
                     opts[name] = True
-                elif optdefs[name] is True:     # --name[=arg]
+                elif spices[name] is True:     # --name[=arg]
                     opts[name] = arg is None and True or arg
-                elif optdefs[name] is 1:        # --name[=N]
+                elif spices[name] is 1:        # --name[=N]
                     if arg and str2int(arg) is None:
                         raise CommandOptionError("%s: integer required." % cmd_arg)
                     opts[name] = arg is None and True or str2int(arg)
                 else:                           # --name=arg
-                    assert isinstance(arg, (str, unicode))
+                    assert _is_str(arg)
                     if arg is None:
                         raise CommandOptionError("%s: argument required." % cmd_arg)
-                    if optdefs[name] == 'N':    # --name=N
+                    if spices[name] == 'N':    # --name=N
                         if str2int(arg) is None:
                             raise CommandOptionError("%s: integer required." % cmd_arg)
                         arg = str2int(arg)
@@ -259,32 +277,32 @@ class CommandOptionParser(object):
                 n = len(optchars)
                 while j < n:
                     ch = optchars[j]
-                    if not optdefs.has_key(ch):
+                    if ch not in spices:
                         raise CommandOptionError("-%s: unknown command option." % ch)
-                    elif optdefs[ch] is False:  # -x
+                    elif spices[ch] is False:  # -x
                         opts[ch] = True
                         j += 1
                         continue
-                    elif optdefs[ch] is True:   # -x[arg]
+                    elif spices[ch] is True:   # -x[arg]
                         opts[ch] = optchars[j+1:] or True
                         break
-                    elif optdefs[ch] is 1:      # -x[N]
+                    elif spices[ch] is 1:      # -x[N]
                         arg = optchars[j+1:]
                         if arg and str2int(arg) is None:
                             raise CommandOptionError("-%s%s: integer required." % (ch, arg))
                         opts[ch] = not arg and True or str2int(arg)
                         break
                     else:                       # -x arg
-                        assert isinstance(optdefs[ch], (str, unicode))
+                        assert _is_str(spices[ch])
                         if optchars[j+1:]:
                             arg = optchars[j+1:]
                         else:
                             assert j + 1 == n
                             i += 1      # not j
                             if i == N:
-                                raise CommandOptionError("-%s: %s required." % (ch, optdefs[ch], ))
+                                raise CommandOptionError("-%s: %s required." % (ch, spices[ch], ))
                             arg = cmd_args[i]
-                        if optdefs[ch] == 'N':  # -x N
+                        if spices[ch] == 'N':  # -x N
                             if str2int(arg) is None:
                                 raise CommandOptionError("-%s %s: integer required." % (ch, arg, ))
                             arg = str2int(arg)
@@ -369,3 +387,19 @@ class CommandOptionParser(object):
 #    #print "*** debug: opts:", repr(opts), ", longopts:", repr(longopts), ", rests:", repr(rests)
 #    return opts, longopts, rests
 #
+
+
+## compatibility for Python 2.x and 3.0
+
+if python2:
+    def _is_str(obj):
+        return isinstance(obj, (str, unicode))  # unicode is not defined in Python 3.0
+    def _get_codeobj(func):
+        return func.func_code
+elif python3:
+    def _is_str(obj):
+        return isinstance(obj, str)
+    def _get_codeobj(func):
+        return func.__code__
+
+
